@@ -39,6 +39,17 @@ Motis2Parser::Motis2Parser(QString locIdentifierType)
     return QDateTime::fromString(timestamp.toString(), Qt::ISODate);
 }
 
+static void parseTimeZone(const QJsonObject &obj, Location &loc)
+{
+    const auto tzId = obj.value("tz"_L1).toString().toUtf8();
+    if (tzId.isEmpty()) {
+        return;
+    }
+    if (const auto tz = QTimeZone(tzId); tz.isValid()) {
+        loc.setTimeZone(tz);
+    }
+}
+
 struct {
     const char *name;
     Line::Mode lineMode;
@@ -73,6 +84,9 @@ struct {
     { "NIGHT_RAIL", Line::Mode::LongDistanceTrain, JourneySection::PublicTransport, IndividualTransport::Walk, IndividualTransport::None, RentalVehicle::Unknown },
     { "REGIONAL_FAST_RAIL", Line::Mode::LocalTrain, JourneySection::PublicTransport, IndividualTransport::Walk, IndividualTransport::None, RentalVehicle::Unknown },
     { "REGIONAL_RAIL", Line::Mode::LocalTrain, JourneySection::PublicTransport, IndividualTransport::Walk, IndividualTransport::None, RentalVehicle::Unknown },
+    { "CABLE_CAR", Line::Mode::Tramway, JourneySection::PublicTransport, IndividualTransport::Walk, IndividualTransport::None, RentalVehicle::Unknown },
+    { "FUNICULAR", Line::Mode::Funicular, JourneySection::PublicTransport, IndividualTransport::Walk, IndividualTransport::None, RentalVehicle::Unknown },
+    { "AREAL_LIFT", Line::Mode::AerialLift, JourneySection::PublicTransport, IndividualTransport::Walk, IndividualTransport::None, RentalVehicle::Unknown },
     { "OTHER", Line::Mode::Unknown, JourneySection::PublicTransport, IndividualTransport::Walk, IndividualTransport::None, RentalVehicle::Unknown },
 };
 
@@ -115,6 +129,7 @@ Stopover Motis2Parser::parsePlace(const QJsonObject &obj, bool hasRealTime) cons
     l.setLatitude(obj.value("lat"_L1).toDouble(NAN));
     l.setLongitude(obj.value("lon"_L1).toDouble(NAN));
     l.setFloorLevel(obj.value("level"_L1).toInt(std::numeric_limits<int>::lowest()));
+    parseTimeZone(obj, l);
     const auto type = obj.value("vertexType"_L1).toString();
     for (const auto &m : vertex_map ) {
         if (QLatin1StringView(m.name) == type) {
@@ -410,6 +425,7 @@ std::vector<Location> Motis2Parser::parseLocations(const QByteArray &data) const
         l.setLatitude(locObj.value("lat"_L1).toDouble());
         l.setLongitude(locObj.value("lon"_L1).toDouble());
         l.setFloorLevel(locObj.value("level"_L1).toInt(std::numeric_limits<int>::lowest()));
+        l.setCountry(locObj.value("country"_L1).toString());
 
         const auto areas = locObj.value("areas"_L1).toArray();
         std::vector<QJsonObject> adminLevels(12);
@@ -422,14 +438,17 @@ std::vector<Location> Motis2Parser::parseLocations(const QByteArray &data) const
             adminLevels[level] = area;
         }
 
-        // resolve country
+        // resolve country if needed
         // we need to do this here rather than relying on post-processing as the subsequent admin level mapping depends on it
-        const auto countryName = adminLevels[2].value("name"_L1).toString();
-        auto country = KCountry::fromName(countryName);
+        auto country = KCountry::fromAlpha2(l.country());
         if (!country.isValid()) {
-            country = KCountry::fromLocation((float)l.latitude(), (float)l.longitude());
+            const auto countryName = adminLevels[2].value("name"_L1).toString();
+            country = KCountry::fromName(countryName);
+            if (!country.isValid()) {
+                country = KCountry::fromLocation((float)l.latitude(), (float)l.longitude());
+            }
+            l.setCountry(country.isValid() ? country.alpha2() : countryName);
         }
-        l.setCountry(country.isValid() ? country.alpha2() : countryName);
 
         // resolve region
         if (const auto r = KCountrySubdivision::fromLocation((float)l.latitude(), (float)l.longitude()); r.isValid()) {
@@ -454,6 +473,8 @@ std::vector<Location> Motis2Parser::parseLocations(const QByteArray &data) const
 
         l.setPostalCode(locObj.value("zip"_L1).toString());
         l.setStreetAddress(QString(locObj.value("street"_L1).toString() + ' '_L1 + locObj.value("houseNumber"_L1).toString()).trimmed());
+
+        parseTimeZone(locObj, l);
         result.push_back(std::move(l));
     }
 
