@@ -18,13 +18,14 @@
 #include <cstring>
 #include <vector>
 
+/** Low-level types and functions to work with raw OSM data as efficiently as possible. */
 namespace OSM {
 
 class DataSet;
 class Member;
 
 /** OSM element identifier. */
-typedef int64_t Id;
+using Id = int64_t;
 
 /** Coordinate, stored as 1e7 * degree to avoid floating point precision issues,
  *  and offset to unsigned values to make the z-order curve work.
@@ -54,17 +55,17 @@ public:
         }
     }
 
-    constexpr inline bool isValid() const
+    [[nodiscard]] constexpr inline bool isValid() const
     {
         return latitude != std::numeric_limits<uint32_t>::max() && longitude != std::numeric_limits<uint32_t>::max();
     }
-    constexpr inline bool operator==(Coordinate other) const
+    [[nodiscard]] constexpr inline bool operator==(Coordinate other) const
     {
         return latitude == other.latitude && longitude == other.longitude;
     }
 
     /** Z-order curve value for this coordinate. */
-    constexpr inline uint64_t z() const
+    [[nodiscard]] constexpr inline uint64_t z() const
     {
         uint64_t z = 0;
         for (int i = 0; i < 32; ++i) {
@@ -74,11 +75,11 @@ public:
         return z;
     }
 
-    constexpr inline double latF() const
+    [[nodiscard]] constexpr inline double latF() const
     {
         return (latitude / 10'000'000.0) - 90.0;
     }
-    constexpr inline double lonF() const
+    [[nodiscard]] constexpr inline double lonF() const
     {
         return (longitude / 10'000'000.0) - 180.0;
     }
@@ -96,34 +97,34 @@ public:
         : min(c1)
         , max(c2)
     {}
-    constexpr inline bool isValid() const
+    [[nodiscard]] constexpr inline bool isValid() const
     {
         return min.isValid() && max.isValid();
     }
-    constexpr inline bool operator==(BoundingBox other) const
+    [[nodiscard]] constexpr inline bool operator==(BoundingBox other) const
     {
         return min == other.min && max == other.max;
     }
 
-    constexpr inline uint32_t width() const
+    [[nodiscard]] constexpr inline uint32_t width() const
     {
         return max.longitude - min.longitude;
     }
-    constexpr inline uint32_t height() const
+    [[nodiscard]] constexpr inline uint32_t height() const
     {
         return max.latitude - min.latitude;
     }
 
-    constexpr inline double widthF() const
+    [[nodiscard]] constexpr inline double widthF() const
     {
         return width() / 10'000'000.0;
     }
-    constexpr inline double heightF() const
+    [[nodiscard]] constexpr inline double heightF() const
     {
         return height() / 10'000'000.0;
     }
 
-    constexpr inline Coordinate center() const
+    [[nodiscard]] constexpr inline Coordinate center() const
     {
         return Coordinate(min.latitude + height() / 2, min.longitude + width() / 2);
     }
@@ -132,7 +133,7 @@ public:
     Coordinate max;
 };
 
-constexpr inline BoundingBox unite(BoundingBox bbox1, BoundingBox bbox2)
+[[nodiscard]] constexpr inline BoundingBox unite(BoundingBox bbox1, BoundingBox bbox2)
 {
     if (!bbox1.isValid()) {
         return bbox2;
@@ -148,24 +149,24 @@ constexpr inline BoundingBox unite(BoundingBox bbox1, BoundingBox bbox2)
     return ret;
 }
 
-constexpr inline bool intersects(BoundingBox bbox1, BoundingBox bbox2)
+[[nodiscard]] constexpr inline bool intersects(BoundingBox bbox1, BoundingBox bbox2)
 {
     return !(bbox2.min.latitude > bbox1.max.latitude || bbox2.max.latitude < bbox1.min.latitude
         || bbox2.min.longitude > bbox1.max.longitude || bbox2.max.longitude < bbox1.min.longitude);
 }
 
-constexpr inline bool contains(BoundingBox bbox, Coordinate coord)
+[[nodiscard]] constexpr inline bool contains(BoundingBox bbox, Coordinate coord)
 {
     return bbox.min.latitude <= coord.latitude && bbox.max.latitude >= coord.latitude
         && bbox.min.longitude <= coord.longitude && bbox.max.longitude >= coord.longitude;
 }
 
-constexpr inline uint32_t latitudeDistance(BoundingBox bbox1, BoundingBox bbox2)
+[[nodiscard]] constexpr inline uint32_t latitudeDistance(BoundingBox bbox1, BoundingBox bbox2)
 {
     return bbox1.max.latitude < bbox2.min.latitude ? bbox2.min.latitude - bbox1.max.latitude : bbox1.min.latitude - bbox2.max.latitude;
 }
 
-constexpr inline uint32_t longitudeDifference(BoundingBox bbox1, BoundingBox bbox2)
+[[nodiscard]] constexpr inline uint32_t longitudeDifference(BoundingBox bbox1, BoundingBox bbox2)
 {
     return bbox1.max.longitude < bbox2.min.longitude ? bbox2.min.longitude - bbox1.max.longitude : bbox1.min.longitude - bbox2.max.longitude;
 }
@@ -205,18 +206,47 @@ private:
 /** An OSM element tag. */
 class Tag {
 public:
-    inline constexpr bool operator<(const Tag &other) const { return key < other.key; }
+    Tag() = default;
+    inline Tag(TagKey _key, QByteArray &&_value)
+        : key(_key)
+        , value(std::move(_value))
+    {}
+    Tag(const Tag&) = default;
+    Tag(Tag &&Tag) noexcept = default;
+    Tag& operator=(const Tag &other) = default;
+    Tag& operator=(Tag &&other) noexcept = default;
+
+    [[nodiscard]] inline constexpr bool operator<(const Tag &other) const { return key < other.key; }
 
     TagKey key;
     QByteArray value;
 };
 
+[[nodiscard]] inline constexpr bool operator<(const Tag &lhs, TagKey rhs) { return lhs.key < rhs; }
+[[nodiscard]] inline constexpr bool operator<(TagKey lhs, const Tag &rhs) { return lhs < rhs.key; }
+
 /** An OSM node. */
 class Node {
 public:
-    constexpr inline bool operator<(const Node &other) const { return id < other.id; }
+    explicit Node() = default;
+    Node(const Node&) = default;
+    Node(Node &&other) noexcept
+    {
+        *this = std::move(other);
+    }
+    Node& operator=(const Node &other) = default;
+    Node& operator=(Node &&other) noexcept
+    {
+        id = other.id;
+        coordinate = other.coordinate;
+        std::swap(tags, other.tags);
+        return *this;
+    }
 
-    QString url() const;
+    [[nodiscard]] constexpr inline bool operator<(const Node &other) const { return id < other.id; }
+    [[nodiscard]] constexpr inline bool operator<(Id other) const { return id < other; };
+
+    [[nodiscard]] QString url() const;
 
     Id id;
     Coordinate coordinate;
@@ -226,11 +256,28 @@ public:
 /** An OSM way. */
 class Way {
 public:
-    constexpr inline bool operator<(const Way &other) const { return id < other.id; }
+    explicit Way() = default;
+    Way(const Way&) = default;
+    Way(Way &&other) noexcept
+    {
+        *this = std::move(other);
+    }
+    Way& operator=(const Way &other) = default;
+    Way& operator=(Way &&other) noexcept
+    {
+        id = other.id;
+        bbox = other.bbox;
+        std::swap(nodes, other.nodes);
+        std::swap(tags, other.tags);
+        return *this;
+    }
 
-    bool isClosed() const;
+    [[nodiscard]] constexpr inline bool operator<(const Way &other) const { return id < other.id; }
+    [[nodiscard]] constexpr inline bool operator<(Id other) const { return id < other; };
 
-    QString url() const;
+    [[nodiscard]] bool isClosed() const;
+
+    [[nodiscard]] QString url() const;
 
     Id id;
     mutable BoundingBox bbox;
@@ -262,11 +309,11 @@ private:
 /** A member in a relation. */
 class Member {
 public:
-    inline bool operator==(const Member &other) const { return id == other.id && m_roleAndType == other.m_roleAndType; }
+    [[nodiscard]] inline bool operator==(const Member &other) const { return id == other.id && m_roleAndType == other.m_roleAndType; }
 
     Id id;
 
-    constexpr inline Role role() const
+    [[nodiscard]] constexpr inline Role role() const
     {
         return Role(m_roleAndType.get());
     }
@@ -275,7 +322,7 @@ public:
         m_roleAndType.set(role.name());
     }
 
-    constexpr inline Type type() const
+    [[nodiscard]] constexpr inline Type type() const
     {
         return static_cast<Type>(m_roleAndType.tag());
     }
@@ -291,9 +338,26 @@ private:
 /** An OSM relation. */
 class Relation {
 public:
-    constexpr inline bool operator<(const Relation &other) const { return id < other.id; }
+    explicit Relation() = default;
+    Relation(const Relation&) = default;
+    Relation(Relation &&other) noexcept
+    {
+        *this = std::move(other);
+    }
+    Relation& operator=(const Relation &other) = default;
+    Relation& operator=(Relation &&other) noexcept
+    {
+        id = other.id;
+        bbox = other.bbox;
+        std::swap(members, other.members);
+        std::swap(tags, other.tags);
+        return *this;
+    }
 
-    QString url() const;
+    [[nodiscard]] constexpr inline bool operator<(const Relation &other) const { return id < other.id; }
+    [[nodiscard]] constexpr inline bool operator<(Id other) const { return id < other; };
+
+    [[nodiscard]] QString url() const;
 
     Id id;
     mutable BoundingBox bbox;
@@ -306,27 +370,27 @@ class DataSet {
 public:
     explicit DataSet();
     DataSet(const DataSet&) = delete;
-    DataSet(DataSet &&other);
+    DataSet(DataSet &&other) noexcept;
     ~DataSet();
 
     DataSet& operator=(const DataSet&) = delete;
-    DataSet& operator=(DataSet &&);
+    DataSet& operator=(DataSet &&) noexcept;
 
     /** Find a node by its id.
      *  @returns @c nullptr if the node doesn't exist.
      */
-    const Node* node(Id id) const;
+    [[nodiscard]] const Node* node(Id id) const;
 
     /** Find a way by its id.
      *  @returns @c nullptr if the way doesn't exist.
      */
-    const Way* way(Id id) const;
-    OSM::Way* way(Id id);
+    [[nodiscard]] const Way* way(Id id) const;
+    [[nodiscard]] Way* way(Id id);
 
     /** Find a relation by its id.
      *  @returns @c nullptr if the relation doesn't exist.
      */
-    const Relation* relation(Id id) const;
+    [[nodiscard]] const Relation* relation(Id id) const;
 
     void addNode(Node &&node);
     void addWay(Way &&way);
@@ -336,7 +400,7 @@ public:
      *  If no key exists, an empty/invalid/null key is returned.
      *  Use this for tag lookup, not for creating/adding tags.
      */
-    TagKey tagKey(const char *keyName) const;
+    [[nodiscard]] TagKey tagKey(const char *keyName) const;
 
     enum StringMemory { StringIsPersistent, StringIsTransient };
     /** Create a tag key for the given tag name. If none exist yet a new one is created.
@@ -345,19 +409,19 @@ public:
      *  instance and thus can be used without requiring a copy. If the memory is transient
      *  the string is copied if needed, and released in the DataSet destructor.
      */
-    TagKey makeTagKey(const char *keyName, StringMemory keyMemOpt = StringIsTransient);
+    [[nodiscard]] TagKey makeTagKey(const char *keyName, StringMemory keyMemOpt = StringIsTransient);
 
     /** Looks up a role name key.
      *  @see tagKey()
      */
-    Role role(const char *roleName) const;
+    [[nodiscard]] Role role(const char *roleName) const;
     /** Creates a role name key.
      *  @see makeTagKey()
      */
-    Role makeRole(const char *roleName, StringMemory memOpt = StringIsTransient);
+    [[nodiscard]] Role makeRole(const char *roleName, StringMemory memOpt = StringIsTransient);
 
     /** Create a unique id for internal use (ie. one that will not clash with official OSM ids). */
-    Id nextInternalId() const;
+    [[nodiscard]] Id nextInternalId() const;
 
     std::vector<Node> nodes;
     std::vector<Way> ways;
@@ -374,9 +438,9 @@ private:
 
 /** Returns the tag value for @p key of @p elem. */
 template <typename Elem>
-inline QByteArray tagValue(const Elem& elem, TagKey key)
+[[nodiscard]] inline QByteArray tagValue(const Elem& elem, TagKey key)
 {
-    const auto it = std::lower_bound(elem.tags.begin(), elem.tags.end(), key, [](const auto &lhs, const auto &rhs) { return lhs.key < rhs; });
+    const auto it = std::lower_bound(elem.tags.begin(), elem.tags.end(), key);
     if (it != elem.tags.end() && (*it).key == key) {
         return (*it).value;
     }
@@ -388,7 +452,7 @@ inline QByteArray tagValue(const Elem& elem, TagKey key)
  *  Where possible avoid this in favor of tagValue().
  */
 template <typename Elem>
-inline QByteArray tagValue(const Elem& elem, const char *keyName)
+[[nodiscard]] inline QByteArray tagValue(const Elem& elem, const char *keyName)
 {
     const auto it = std::find_if(elem.tags.begin(), elem.tags.end(), [keyName](const auto &tag) { return std::strcmp(tag.key.name(), keyName) == 0; });
     if (it != elem.tags.end()) {
@@ -454,16 +518,19 @@ inline void setTag(Elem &elem, Tag &&tag)
 
 /** Inserts a new tag, or updates an existing one. */
 template <typename Elem>
-inline void setTagValue(Elem &elem, TagKey key, const QByteArray &value)
+inline void setTagValue(Elem &elem, TagKey key, QByteArray &&value)
 {
-    Tag tag{ key, value };
-    setTag(elem, std::move(tag));
+    setTag(elem, Tag(key, std::move(value)));
 }
 
+/** Removes a tag from the given element. */
 template <typename Elem>
-inline bool operator<(const Elem &elem, Id id)
+inline void removeTag(Elem &elem, TagKey key)
 {
-    return elem.id < id;
+    const auto it = std::lower_bound(elem.tags.begin(), elem.tags.end(), key);
+    if (it != elem.tags.end() && (*it).key == key) {
+        elem.tags.erase(it);
+    }
 }
 
 }
